<?php

// Change to squidGuard and sarg config file paths
$SargConf = "/usr/local/sarg/sarg.conf";
$squidGuardConf = "/usr/local/squidGuard/squidGuard.conf";

// File where URL to block will be appended
$DefaultSquidBlock = "/usr/local/squid/etc/block.txt";

// Choose the locale you want to use to display messages (it must exist on your system)
$language = "fr_BE.utf-8";

?>
